@@ -11,7 +11,7 @@ import sys
 # to stay secure?
 # TODO: Stop being lame and find a way to make this more secure.
 from importlib import import_module
-
+import getopt
 from wsunittest import *
 
 
@@ -26,9 +26,7 @@ def module_exists(module_name):
 
 
 class unittestWebSocketHandler(tornado.websocket.WebSocketHandler):
-    """
-    A Tornado websocket server that outputs flat text from incoming test requests.
-    """
+    """A Tornado websocket server that outputs flat text from incoming test requests."""
     def is_valid_module(self, module):
         # TODO: valid modules should be in a config file or something like that.
         return True
@@ -54,11 +52,8 @@ class unittestWebSocketHandler(tornado.websocket.WebSocketHandler):
         if module:
             # TODO: Reload module if the module has already been loaded. (reload(module))
             # You may pass the port to the server by commandline; this removes it.
-            argv = sys.argv
-            argv.pop(argv.index("port"))
             return unittestWebSocketTestProgram(
                 module=import_module(module),
-                argv=argv,
                 testRunner=webSocketTestRunner(stream=self)
             )
 
